<?php
/**
 * Custom and output functions for the theme customizer
 *
 * @package    Silver
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'silver_mod' ) ) :
/**
 * Wrap get_theme_mod function
 */
function silver_mod( $name ) {

	// Allow to filter the customizer.
	return apply_filters( 'silver_mod', get_theme_mod( $name, customizer_library_get_default( $name ) ), PREFIX, $name );

}
endif;

/**
 * Custom customizer function.
 *
 * @since  1.0.0
 */
function silver_move_default_customizer( $wp_customize ) {

	// Live preview
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Remove sections
	$wp_customize->remove_section( 'background_image' );

}
add_action( 'customize_register', 'silver_move_default_customizer', 99 );

if ( ! function_exists( 'silver_tags_list' ) ) :
/**
 * Retrieve tags list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function silver_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = esc_html__( 'Select a tag &hellip;', 'silver' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}
endif;

if ( ! function_exists( 'silver_cats_list' ) ) :
/**
 * Retrieve categories list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function silver_cats_list() {

	// Set up empty array.
	$cats = array();

	// Retrieve available categories.
	$cats_obj = get_categories();

	// Set default/empty tag.
	$cats[''] = esc_html__( 'Select a category &hellip;', 'silver' );

	// Display the tags.
	foreach ( $cats_obj as $cat ) {
		$cats[$cat->term_id] = esc_attr( $cat->name );
	}

	return $cats;

}
endif;

/**
 * Display theme documentation on customizer page.
 *
 * @since  1.0.0
 */
function silver_documentation_link() {

	// Enqueue the script
	wp_enqueue_script(
		PREFIX . 'customizer-doc',
		get_template_directory_uri() . '/admin/js/doc.js',
		array(), '1.0.0',
		true
	);

	// Localize the script
	wp_localize_script(
		PREFIX . 'customizer-doc',
		'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/silver' ),
			'prefixLabel' => esc_html__( 'Documentation', 'silver' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'silver_documentation_link' );
